diff --git a/Build/Changes.txt b/Build/Changes.txt
index 3b9345d55..0cf89a23c 100644
--- a/Build/Changes.txt
+++ b/Build/Changes.txt
@@ -2,6 +2,56 @@
Rizonesoft Notepad3 CHANGES
==================================================
+--------------------------------------------------
+Version 3.17.1223.773 (23 December 2017)
+--------------------------------------------------
+- Fix: Hyperlink feature related delay of font changing.
+- Added more triggers for Hyperlink style updated.
+- Refactoring: Cleanup trigger points for URL Hotspot styling.
+- Fix: Last hyperlink was restyled to lexer's style (not desired hotspot style).
+- Feature: Replaced DeelX with Onigmo regular expression engine.
+- Fix: Default lexer style changed a litle bit after first UI update.
+- Fix: Redraw bug in case of SCI_COLOURISE.
+- Fix: Removed some Hyperlink dection triggerpoints, which might be collide with SEARCHINTARGET and REPLACETARGET race conditions (seperate threads).
+- Fix: Removed unneccessary Hyperlink trigger-point from InitInstance().
+- Fix: Performance issue while pasting long text from clipboard.
+- Fix: Local memory freeing.
+- Fix: Complete set of font weights for syntax scheme.
+- Fix: Prepare fixing race-condition search/replace target vs. selection.
+- Fix: Set target range only for search/replace and not for paste after modifying selection (race-condition search/replace target vs. selection).
+- Fix: Transform backslashes for regex find/replace.
+- Feature: Added Scintilla's indicator styles to scheme config for "Mark Occurences".
+- Fix: Out of range fallback for indicator string retrieval.
+- Fix: Issue regarding TransformBackslash handler (regex vs. std & find vs. replace).
+- Fix: Replace dialog: Resize regex text box to not overlay other control.
+- Fix: Enable more hyperlink styling trigger points, since "replace target" race-conditions have been fixed and fast regex engine (Onigmo) is integrated.
+- Fix: Issue regarding applying lexer style while hyperlink feature is active.
+- Fix: Reverting to buffered draw, until screen flickering issues are clarified.
+- Fix: Onigmo regex engine handling string/line end meta char '$' independent of EOL mode.
+- Fix: Replace-all with look-behind assertion.
+- Update: uthash to version 2.0.2.
+- Fix: Onigmo word boundaries issues (incl. "double" escaped esc) (not solved yet: multi escaped esc).
+- Fix: Customize schemes issues (now Default Font: is applied to "Default Text" and "Current Lexers" Default Font).
+- Fix: Allow (horiz.)TAB chars in selection copied to find/replace dialog search box on pop up time (Ctrl+F).
+- Fix: Setting "Default Font..." will clear current lexer's default font - inherits global default font then.
+- Fix: "Default Font..." configuration issue.
+- Minor fixes for Onigmo interface class.
+- Fix: "Default Font..." add check for current scheme is not default text already.
+- Enhanced style copy method.
+- Refactoring: Style Select Font dialog.
+- Fix: Schemes in alphabetical order (displayed names).
+- Feature: Dual configuration of Default Text Font or Current Scheme's Default Text Font.
+- Fix: Bug on font selection - global vs. current scheme.
+- Fix: More bugs regarding standard lexer handling.
+- Fix: Using WYSIWYG fonts (screen vs. printer).
+- Added Online Documentation menu item.
+- Fix: Inconsistencies: cut,copy,replace,... mainmenu and context menu vs. toolbar.
+- Fix: New Font selection feature: 2nd Default Font not supported completely.
+- Fix: setting/changing encryption pass-phrase did not trigger "file modified" flag.
+- Fix: Problem with 1st vs. 2nd Default Text Scheme selection.
+- Fix: Inconsistency 1st vs. 2nd Default Text Font selection.
+- General bug fixes and code cleanup.
+
--------------------------------------------------
Version 3.17.1210.729 (10 December 2017)
--------------------------------------------------
diff --git a/Build/Readme.txt b/Build/Readme.txt
index fb2a4ea98..78c25939a 100644
--- a/Build/Readme.txt
+++ b/Build/Readme.txt
@@ -2,37 +2,67 @@
= =
= Notepad3 - light-weight Scintilla-based text editor for Windows =
= =
-= (c) Rizonesoft 2008-2016 =
-= https://rizonesoft.com =
+= (c) Rizonesoft 2008-2018 =
+= https://www.rizonesoft.com =
= =
================================================================================
+Description
+--------------------------------------------------------------------------------
+Notepad like text editor based on the Scintilla source code. Notepad3 based on
+code from Notepad2 and MiniPath on code from metapath.
-Notepad3 is based on code from Florian Balmer's Notepad2 and
-XhmikosR's Notepad2-mod.
-
-Changes compared to Notepad2
+--------------------------------------------------------------------------------
+Changes compared to Flo's official Notepad2 (made in Notepad2-mod):
+--------------------------------------------------------------------------------
+- Code folding
+- Support for bookmarks
+- Option to mark all occurrences of a word
+- Updated Scintilla component
+- Word auto-completion
+- Syntax highlighting support for AutoHotkey (AHK), AutoIt3, AviSynth, Bash,
+ CMake, CoffeeScript, Inno Setup, LaTeX, Lua, Markdown, NSIS, Ruby, Tcl,
+ YAML and VHDL scripts.
+- Improved support for NFO ANSI art
+- Other various minor changes and tweaks
- - Code folding
- - Support for bookmarks
- - Option to mark all occurrences of a word
- - Word auto-completion
- - Syntax highlighting support for AutoHotkey, AutoIt3, AviSynth, Bash, CMake,
- CoffeeScript, Inno Setup, LaTeX, Lua, Markdown, NSIS, Ruby, Tcl,
- YAML and VHDL scripts
- - Improved support for NFO ANSI art
- - Support for replacing Windows Notepad using a clean, unintrusive
- registry-based method.
- - Other various minor changes and tweaks
-
-Supported Operating Systems
+--------------------------------------------------------------------------------
+Changes compared to the Notepad2-mod fork:
+--------------------------------------------------------------------------------
+- Additional syntax highlighting support for Awk, D, golang, MATLAB
+- State of the art Regular Expression search engine (Onigmu)
+- New toolbar icons based on Yusuke Kamiyaman's Fugue Icons
+ (Purchased by Rizonesoft)
+- Hyperlink Hotspot highlighting
+ (single click Open in Browser (Ctrl) / Load in Editor (Alt))
+- New program icon and other small cosmetic changes
+- In-App support for AES-256 Rijndael encryption/decryption of files.
+ (incl. external commandline tool for batch processing)
+- Virtual Space rectangular selection box (Alt-Key down)
+- High-DPI awareness, including high definition toolbar icons
+- Undo/Redo preserves selection
+- File History preserves Caret position (optional)
+ and remembers encoding of file
+- Accelerated word navigation
+- Preserve caret position of items in file history
+- Count occurrences of a marked selection or word
+- Count and Mark occurrences of matching search/find expression
+- Visual Studio style copy/paste current line (no selection)
+- Insert GUIDs
+- Dropped support for Windows XP version
+- Other various minor changes, tweaks and bugfixes
- Windows XP (SP3), Vista, 7, 8, 8.1, 10 both 32-bit and 64-bit
+--------------------------------------------------------------------------------
+Supported Operating Systems:
+--------------------------------------------------------------------------------
+Windows 7, 8, 8.1 and 10 both 32-bit and 64-bit
+--------------------------------------------------------------------------------
Contributors
-
- - Florian Balmer ( http://www.flos-freeware.ch )
- - XhmikosR ( http://xhmikosr.github.io/notepad2-mod/ )
- - Kai Liu ( http://code.kliu.org/misc/notepad2/ )
- - RL Vision
- - Aleksandar Lekov
- - Bruno Barbieri
\ No newline at end of file
+--------------------------------------------------------------------------------
+- Rainer Kottenhoff
+- Florian Balmer ( http://www.flos-freeware.ch )
+- XhmikosR ( http://xhmikosr.github.io/notepad2-mod/ )
+- Kai Liu ( http://code.kliu.org/misc/notepad2/ )
+- RL Vision
+- Aleksandar Lekov
+- Bruno Barbieri
\ No newline at end of file
diff --git a/Versions/build.txt b/Versions/build.txt
index 72c2a20c9..9e7e0ab23 100644
--- a/Versions/build.txt
+++ b/Versions/build.txt
@@ -1 +1 @@
-761
+773
diff --git a/res/Notepad3.exe.manifest.conf b/res/Notepad3.exe.manifest.conf
index ca71571ce..750058acf 100644
--- a/res/Notepad3.exe.manifest.conf
+++ b/res/Notepad3.exe.manifest.conf
@@ -3,7 +3,7 @@
Notepad3
diff --git a/src/Notepad3.c b/src/Notepad3.c
index 893c61548..435348410 100644
--- a/src/Notepad3.c
+++ b/src/Notepad3.c
@@ -1159,11 +1159,9 @@ LRESULT CALLBACK MainWndProc(HWND hwnd,UINT umsg,WPARAM wParam,LPARAM lParam)
// update Scintilla colors
case WM_SYSCOLORCHANGE:
- {
- Style_SetLexer(g_hwndEdit,NULL); // uses current lexer
- UpdateLineNumberWidth();
- return DefWindowProc(hwnd,umsg,wParam,lParam);
- }
+ SendMessage(g_hwndEdit, SCI_COLOURISE, 0, (LPARAM)-1);
+ UpdateLineNumberWidth();
+ return DefWindowProc(hwnd,umsg,wParam,lParam);
//case WM_TIMER:
// return DefWindowProc(hwnd,umsg,wParam,lParam);
diff --git a/src/VersionEx.h b/src/VersionEx.h
index c3f49c1fc..e2baf0179 100644
--- a/src/VersionEx.h
+++ b/src/VersionEx.h
@@ -5,7 +5,7 @@
// //////////////////////////////////////////////////////////
#define VERSION_MAJOR 3
#define VERSION_MINOR 17
-#define VERSION_REV 1220
-#define VERSION_BUILD 758
+#define VERSION_REV 1223
+#define VERSION_BUILD 773
#define SCINTILLA_VER 402
#define ONIGMO_REGEX_VER 6.1.3
diff --git a/src/Styles.c b/src/Styles.c
index 02bac0c56..0073f3503 100644
--- a/src/Styles.c
+++ b/src/Styles.c
@@ -3129,9 +3129,9 @@ void Style_SetLexer(HWND hwnd, PEDITLEXER pLexNew) {
WCHAR wchFontName[64] = { '\0' };
WCHAR wchCaretStyle[64] = { L'\0' };
// Select current if NULL is specified
if (!pLexNew) {
- pLexNew = g_pLexCurrent; // initially current lexer is default lexer
+ pLexNew = &lexStandard;
}
// Lexer
@@ -3129,9 +3129,9 @@ void Style_SetLexer(HWND hwnd, PEDITLEXER pLexNew) {
WCHAR wchFontName[64] = { '\0' };
WCHAR wchCaretStyle[64] = { L'\0' };
- // Select current if NULL is specified
+ // Select standard if NULL is specified
if (!pLexNew) {